@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2021 Aleo Systems Inc.
+// Copyright (C) 2019-2022 Aleo Systems Inc.
 // This file is part of the snarkOS library.
 
 // The snarkOS library is free software: you can redistribute it and/or modify
@@ -14,32 +14,24 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkOS library. If not, see <https://www.gnu.org/licenses/>.
 
-pub mod exporter;
-pub use exporter::*;
+#![forbid(unsafe_code)]
+#![allow(clippy::type_complexity)]
 
-pub mod ledger;
-pub use ledger::*;
+#[macro_use]
+extern crate tracing;
 
-pub mod key_value;
-pub use key_value::*;
+mod helpers;
+pub use helpers::BlockLocators;
 
-pub mod objects;
-pub use objects::*;
+pub(crate) mod state;
+pub use state::{
+    LedgerState,
+    Metadata,
+    OperatorState,
+    ProverState,
+    MAXIMUM_BLOCK_LOCATORS,
+    MAXIMUM_LINEAR_BLOCK_LOCATORS,
+    MAXIMUM_QUADRATIC_BLOCK_LOCATORS,
+};
 
-pub mod trim;
-pub use trim::*;
-
-pub mod mem;
-#[cfg(feature = "mem_storage")]
-pub use mem::MemDb as LedgerStorage;
-
-#[cfg(feature = "rocksdb_storage")]
-mod rocks;
-#[cfg(feature = "rocksdb_storage")]
-pub use rocks::RocksDb as LedgerStorage;
-
-pub mod validator;
-pub use validator::*;
-
-/// The number of block hashes that are returned by the `Ledger::get_block_locator_hashes` call.
-pub const NUM_LOCATOR_HASHES: u32 = 64;
+pub mod storage;
